==> igniteui-webcomponents-layouts-5.0.1.tgz: package/esm5/lib/igc-tool-action-icon-menu-component.js <==
import { __extends } from "tslib";
import { IgcToolActionIconButtonComponent } from "./igc-tool-action-icon-button-component";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionIconMenuComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionIconMenuComponent, _super);
    function IgcToolActionIconMenuComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionIconMenuComponent.prototype.createImplementation = function () {
        return new ToolActionIconMenu();
    };
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconMenuComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionIconMenuComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionIconMenuComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent == null) {
                var names = getAllPropertyNames(IgcToolActionIconMenuComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = names;
            }
            return IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconMenuComponent.register = function () {
        if (!IgcToolActionIconMenuComponent._isElementRegistered) {
            IgcToolActionIconMenuComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionIconMenuComponent.htmlTagName, IgcToolActionIconMenuComponent);
        }
    };
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "arrowStroke", {
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.ju);
        },
        set: function (v) {
            this.i.ju = stringToBrush(v);
            this._a("arrowStroke", brushToString(this.i.ju));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "actualArrowStroke", {
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.jt);
        },
        set: function (v) {
            this.i.jt = stringToBrush(v);
            this._a("actualArrowStroke", brushToString(this.i.jt));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "showArrowIcon", {
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get: function () {
            return this.i.jg;
        },
        set: function (v) {
            this.i.jg = ensureBool(v);
            this._a("showArrowIcon", this.i.jg);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconMenuComponent.prototype.exportVisualData = function () {
        var iv = this.i.cn();
        return (iv);
    };
    IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = null;
    IgcToolActionIconMenuComponent.htmlTagName = "igc-tool-action-icon-menu";
    IgcToolActionIconMenuComponent._isElementRegistered = false;
    return IgcToolActionIconMenuComponent;
}(IgcToolActionIconButtonComponent));
export { IgcToolActionIconMenuComponent };

==> igniteui-webcomponents-layouts-5.1.0.tgz: package/esm5/lib/igc-tool-action-icon-menu-component.js <==
import { __extends } from "tslib";
import { IgcToolActionIconButtonComponent } from "./igc-tool-action-icon-button-component";
import { ToolActionIconMenu } from "./ToolActionIconMenu";
import { getAllPropertyNames, toSpinal, brushToString, stringToBrush, ensureBool } from "igniteui-webcomponents-core";
import { RegisterElementHelper } from "igniteui-webcomponents-core";
var IgcToolActionIconMenuComponent = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgcToolActionIconMenuComponent, _super);
    function IgcToolActionIconMenuComponent() {
        return _super.call(this) || this;
    }
    IgcToolActionIconMenuComponent.prototype.createImplementation = function () {
        return new ToolActionIconMenu();
    };
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconMenuComponent.prototype.connectedCallback = function () {
        if (_super.prototype["connectedCallback"]) {
            _super.prototype["connectedCallback"].call(this);
        }
        if (this.i.connectedCallback) {
            this.i.connectedCallback();
        }
        if (!this._attached) {
            this._attached = true;
            this._flushQueuedAttributes();
        }
    };
    IgcToolActionIconMenuComponent.prototype.disconnectedCallback = function () {
        if (_super.prototype["disconnectedCallback"]) {
            _super.prototype["disconnectedCallback"].call(this);
        }
        if (this.i.disconnectedCallback) {
            this.i.disconnectedCallback();
        }
        if (this._attached) {
            this._attached = false;
        }
    };
    Object.defineProperty(IgcToolActionIconMenuComponent, "observedAttributes", {
        get: function () {
            if (IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent == null) {
                var names = getAllPropertyNames(IgcToolActionIconMenuComponent);
                for (var i = 0; i < names.length; i++) {
                    names[i] = toSpinal(names[i]);
                }
                IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = names;
            }
            return IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent;
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconMenuComponent.register = function () {
        if (!IgcToolActionIconMenuComponent._isElementRegistered) {
            IgcToolActionIconMenuComponent._isElementRegistered = true;
            RegisterElementHelper.registerElement(IgcToolActionIconMenuComponent.htmlTagName, IgcToolActionIconMenuComponent);
        }
    };
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "arrowStroke", {
        /**
         * Gets or sets the stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.jv);
        },
        set: function (v) {
            this.i.jv = stringToBrush(v);
            this._a("arrowStroke", brushToString(this.i.jv));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "actualArrowStroke", {
        /**
         * Gets the actual stroke color of the arrow icon.
        */
        get: function () {
            return brushToString(this.i.ju);
        },
        set: function (v) {
            this.i.ju = stringToBrush(v);
            this._a("actualArrowStroke", brushToString(this.i.ju));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgcToolActionIconMenuComponent.prototype, "showArrowIcon", {
        /**
         * Gets or sets whether the arrow icon should be shown.
        */
        get: function () {
            return this.i.jh;
        },
        set: function (v) {
            this.i.jh = ensureBool(v);
            this._a("showArrowIcon", this.i.jh);
        },
        enumerable: false,
        configurable: true
    });
    IgcToolActionIconMenuComponent.prototype.exportVisualData = function () {
        var iv = this.i.cn();
        return (iv);
    };
    IgcToolActionIconMenuComponent._observedAttributesIgcToolActionIconMenuComponent = null;
    IgcToolActionIconMenuComponent.htmlTagName = "igc-tool-action-icon-menu";
    IgcToolActionIconMenuComponent._isElementRegistered = false;
    return IgcToolActionIconMenuComponent;
}(IgcToolActionIconButtonComponent));
export { IgcToolActionIconMenuComponent };
